<?php

    namespace TalkJS\Admin;

    use TalkJS\Helpers\Url;
    use TalkJS\Helpers\User;
    use TalkJS\Facades\Field;
    use TalkJS\Helpers\Roles;
    use TalkJS\Facades\Markup;
    use TalkJS\Helpers\Settings;
	use TalkJS\Helpers\PostTypes;
	use TalkJS\Facades\SettingsPage;
	use TalkJS\Contracts\EventsInstance;

	class OnboardingPageCreator extends EventsInstance{

        /**
         * Listen to onboarding events
         *
         * @return void
         */
        public function listen()
        {
            add_action( 'wp_loaded', function(){

                if( Settings::isOnboarding() ){

                    SettingsPage::make(

                        __( 'Welcome to TalkJS!', 'talkjs' ),
                        Settings::onboardingPage(),
                        [
                            'parent' => 'options-general.php',
                            'buttonText' => __( 'Next', 'talkjs' ),
                            'dataset' => Settings::optionName()
                        ]

                    )->set( $this->getObjects() );

                }

			});
        }


        /**
         * Returns the right objects
         *
         * @return Array
         */
        public function getObjects(){

            return [

                Markup::paragraph(
                    "This plugin connects the <a href=\"%s\" target=\"_blank\">TalkJS user-to-user chat service</a> to your WordPress site.\n\n
                    If you didn't yet, you need to <a href=\"%s\" target=\"_blank\">make a TalkJS account</a>.
                    Then log into the <a href=\"%s\" target=\"_blank\">TalkJS Dashboard</a>, find your 'appId', and fill it out below.",
                    Url::site(),
                    Url::account(),
                    Url::dashboard()
                ),
                Field::text( 'test_appid', [
					'label' => __( 'Test App ID', 'talkjs' ),
					'placeholder' => __( 'Your TalkJS Test App ID', 'talkjs' ),
					'value' => Settings::get('test_appid', '' ),
					'classes' => ['check-test-connection', 'check-appid'],
					'validation' => ['valid-connection']
				]),

				Field::text( 'test_secretkey', [
					'label' => __( 'Test Secret Key', 'talkjs' ),
					'placeholder' => __( 'Your TalkJS Test Secret Key','talkjs' ),
					'value' => Settings::get( 'test_secretkey', '' ),
					'classes' => ['check-test-connection', 'check-secretkey'],
					'validation' => ['valid-connection']
                ]),

                Markup::heading(
                    'User roles & configurations',
                    'h3'
                ),

                Markup::paragraph(
                    __( "TalkJS allows you to change most if its behavior in the <a href=\"%s\" target=\"_blank\">TalkJS Dashboard</a>. For instance, you can fine-tune the look & feel of the chat, set up email and sms notifications, suppress contact information in user messages, and so on. \n\n
                    You can choose different settings for each User Role of your WordPress site.", 'talkjs' ),
                    Url::dashboard()
                ),

                Field::checkboxes( 'userTypes', [
                    'label' => __( 'Which User Roles are allowed to chat on your site?', 'talkjs' ),
                    'value' => Settings::get( 'userTypes', [] ),
                    'choices' => Roles::forCheckboxes(),
                    'classes' => ['check-configurations', 'help-below'],
                    'validation' => 'valid-array'
                ]),

                Markup::paragraph(
                    __( "You must make a \"user configuration\" in the <a href=\"%s\" target=\"_blank\">TalkJS Dashboard</a> for every user role you selected above. Make sure the configuration names you choose precisely match the name of the role.", 'talkjs' ),
                    Url::dashboard()
                )

            ];
        }

        /**
         * Returns the right fields
         *
         * @return Array
         */
        public function getFields(){

            $fields = [];
            $objects = $this->getObjects();

            foreach( $objects as $obj ){

                if( method_exists( $obj, 'getName' ) )
                    $fields[] = $obj;
            }

            return $fields;
        }

    }

    OnboardingPageCreator::getInstance();
