<?php

	namespace TalkJS\Admin;

    use TalkJS\Helpers\Url;
    use TalkJS\Helpers\User;
    use TalkJS\Facades\Field;
    use TalkJS\Helpers\Roles;
    use TalkJS\Facades\Markup;
    use TalkJS\Helpers\Settings;
	use TalkJS\Helpers\PostTypes;
	use TalkJS\Facades\SettingsPage;
	use TalkJS\Contracts\EventsInstance;

	class SettingsPageCreator extends EventsInstance{


		/**
		 * Listener
		 *
		 * @return void
		 */
		public function listen()
		{
			add_action( 'wp_loaded', function(){

				SettingsPage::make(

					__( 'TalkJS Settings', 'talkjs' ),
					Settings::page(),
					[ 'parent' => 'options-general.php' ]

				)->set( $this->getObjects() );

			});
		}


		/**
		 * Return the fields for our settings page
		 *
		 * @return Array
		 */
		public function getObjects()
		{
			$fields = [

                Markup::paragraph(
                    __( "This plugin connects the <a href=\"%s\">TalkJS user-to-user chat service</a> to your WordPress site.\n\n
                    TalkJS includes an \"Inbox page\", with the current user's full conversation history.
                    We already created such a page for you, <a href=\"%s\">set it up here</a>", 'talkjs' ),
                    Url::site(),
                    Url::inboxPage()
                ),

                Markup::heading(
                    __( "TalkJS Credentials", 'talkjs'),
                    'h3',
                    'border-top'
                ),

                Markup::paragraph(
                    __( "TalkJS can run in test mode and in live mode. Test mode is free forever
                    but you're not allowed to use it for anything other than testing.\n\n
                    When you signed up, you immediately got access to the TalkJS test mode app id:", 'talkjs' )
                ),

				Field::text( 'test_appid', [
					'label' => __( 'Test App ID', 'talkjs' ),
					'placeholder' => __( 'Your TalkJS Test App ID', 'talkjs' ),
					'value' => Settings::get('test_appid', '' ),
					'classes' => ['check-test-connection', 'check-appid'],
					'validation' => ['valid-connection']
				]),

				Field::text( 'test_secretkey', [
					'label' => __( 'Test Secret Key', 'talkjs' ),
					'placeholder' => __( 'Your TalkJS Test Secret Key','talkjs' ),
					'value' => Settings::get( 'test_secretkey', '' ),
					'classes' => ['check-test-connection', 'check-secretkey'],
					'validation' => ['valid-connection']
				]),


                Markup::paragraph(
                    __( "If you want to go live with real users, go to the <a href=\"%s\">TalkJS Dashboard</a>,
                provide payment information, and then copy the live mode app id here:", 'talkjs' ),
                    Url::dashboard()
                ),

				Field::text( 'appid', [
					'label' => __( 'App ID', 'talkjs' ),
					'placeholder' => __( 'Your TalkJS App ID', 'talkjs' ),
					'value' => Settings::get('appid', '' ),
					'classes' => ['check-connection', 'check-appid'],
					'validation' => ['valid-connection']
				]),

				Field::text( 'secretkey', [
					'label' => __( 'Secret Key', 'talkjs' ),
					'placeholder' => __( 'Your TalkJS Secret Key','talkjs' ),
					'value' => Settings::get( 'secretkey', '' ),
					'classes' => ['check-connection', 'check-secretkey'],
					'validation' => ['valid-connection']
				]),

                Markup::heading(
                    __( "Customization", 'talkjs' ),
                    'h3',
                    'border-top'
                ),

				Field::textarea( 'welcomeMessage', [
					'label' => __( 'Default welcome message - this is an automatically generated message that is shown to users when they start a chat.', 'talkjs' ),
                    'value' => Settings::get( 'welcomeMessage' ),
                    'help' => __( 'this is an automatically generated message that is shown to users when they start a chat.', 'talkjs' ),
                    'validation' => 'valid-string'
				]),

				Field::checkboxes( 'postTypes', [
					'label' => __( 'Auto-show a chat popup button on single views of the following post-types', 'talkjs'),
					'value' => Settings::get( 'postTypes', [] ),
                    'choices' => PostTypes::all(),
                    'validation' => 'valid-array'
                ]),

                Field::checkboxes( 'authorTypes', [
                    'label' => __( 'Always show the chat popup button on these profile pages', 'talkjs' ),
                    'value' => Settings::get( 'authorTypes', [] ),
                    'choices' => Roles::forCheckboxes(),
                    'validation' => 'valid-array'
                ]),

                Field::checkboxes( 'userTypes', [
                    'label' => __( 'Which User Roles are allowed to chat on your site?', 'talkjs' ),
                    'value' => Settings::get( 'userTypes', [] ),
                    'choices' => Roles::forCheckboxes(),
                    'classes' => ['check-configurations'],
                    'validation' => 'valid-array'
                ]),

				Field::checkbox( 'keepLivePopup', [
					'label' => __( 'Keep popup open when the user navigates between pages', 'talkjs' ),
                    'value' => Settings::get( 'keepLivePopup', false ),
                    'validation' => 'valid-boolean'
                ]),

                Markup::paragraph(
                    __( "Interested in further customization? <a href=\"%s\" target=\"_blank\">Check our developer documentation</a>", 'talkjs' ),
                    Url::docs()
                )

			];

			return $fields;

        }

        /**
         * Returns only the fields:
         *
         * @return Array
         */
        public function getFields(){
            $fields = [];
            $objects = $this->getObjects();

            foreach( $objects as $obj ){
                if( method_exists( $obj, 'getName' ) )
                    $fields[] = $obj;
            }

            return $fields;
        }
	}



	if( is_admin() )
		\TalkJS\Admin\SettingsPageCreator::getInstance();
